spannertools.is_component_with_spanner_attached
===============================================

.. autofunction:: abjad.tools.spannertools.is_component_with_spanner_attached.is_component_with_spanner_attached
